@@ -123,6 +123,16 @@ class Benchmark(object):
         """Set file path reference"""
         self._file_path_ref = file_path_ref
 
+    @property
+    def outpath(self):
+        """Return outpath"""
+        return self._outpath
+
+    @outpath.setter
+    def outpath(self, new_outpath):
+        """Overwrite outpath"""
+        self._outpath = new_outpath
+
     @property
     def substitutesets(self):
         """Return substitutesets"""
@@ -133,6 +143,10 @@ class Benchmark(object):
         """Return workpackages"""
         return self._workpackages
 
+    def add_tags(self, other_tags):
+        if other_tags is not None:
+            self._tags = self._tags.union(set(other_tags))
+
     def workpackage_by_id(self, wp_id):
         """Search and return a benchmark workpackage by its wp_id"""
         for stepname in self._workpackages:
@@ -335,7 +349,7 @@ class Benchmark(object):
         if show_info:
             LOGGER.info(">>> Analyse finished")
 
-    def create_result(self, only=None, show=False, data_list=None):
+    def create_result(self, only=None, show=False, data_list=None, style=None):
         """Show benchmark result"""
         if only is None:
             only = [result_name for result_name in self._results]
@@ -344,7 +358,7 @@ class Benchmark(object):
         for result_name in self._results_order:
             result = self._results[result_name]
             if result.name in only:
-                result_data = result.create_result_data()
+                result_data = result.create_result_data(style)
                 if result.result_dir is None:
                     result_dir = os.path.join(self.bench_dir,
                                               jube2.conf.RESULT_DIRNAME)
@@ -542,6 +556,11 @@ class Benchmark(object):
         # Change logfile
         jube2.log.change_logfile_name(os.path.join(
             self.bench_dir, jube2.conf.LOGFILE_RUN_NAME))
+        # Move parse logfile into benchmark folder
+        if os.path.isfile(jube2.conf.DEFAULT_LOGFILE_NAME):
+            os.rename(jube2.conf.DEFAULT_LOGFILE_NAME,
+                      os.path.join(self.bench_dir,
+                                   jube2.conf.LOGFILE_PARSE_NAME))
 
         # Reset Workpackage counter
         jube2.workpackage.Workpackage.id_counter = 0
@@ -561,6 +580,7 @@ class Benchmark(object):
     def run(self):
         """Run benchmark"""
         title = "benchmark: {0}".format(self._name)
+        title += "\nid: {0}".format(self._id)
         if jube2.conf.DEBUG_MODE:
             title += " ---DEBUG_MODE---"
         title += "\n\n{0}".format(self._comment)
@@ -671,7 +691,6 @@ class Benchmark(object):
         # Create root-tag and append single benchmark
         benchmarks_etree = ET.Element("jube")
         benchmarks_etree.attrib["version"] = jube2.conf.JUBE_VERSION
-
         # Store tag information
         if len(self._tags) > 0:
             selection_etree = ET.SubElement(benchmarks_etree, "selection")
