@@ -1226,8 +1226,7 @@ class XMLParser(object):
                     .format(parameter_update_mode, name))
             export_str = param.get("export", default="false").strip()
             export = export_str.lower() == "true"
-            if parameter_mode not in \
-                    set(["text"]).union(jube2.conf.ALLOWED_SCRIPTTYPES):
+            if parameter_mode not in jube2.conf.ALLOWED_MODETYPES:
                 raise ValueError(
                     ("parameter-mode \"{0}\" not allowed in " +
                      "<parameter name=\"{1}\">").format(parameter_mode,
@@ -1315,6 +1314,8 @@ class XMLParser(object):
                     pattern_mode, name))
             content_type = pattern.get("type", default="string").strip()
             unit = pattern.get("unit", "").strip()
+            dotall = \
+                pattern.get("dotall", "true").strip().lower() == "true"
             default = pattern.get("default")
             if default is not None:
                 default = default.strip()
@@ -1324,7 +1325,7 @@ class XMLParser(object):
                 value = pattern.text.strip()
             patternlist.append(jube2.pattern.Pattern(name, value, pattern_mode,
                                                      content_type, unit,
-                                                     default))
+                                                     default, dotall))
         return patternlist
 
     def _extract_filesets(self, etree):
