@@ -75,6 +75,7 @@ def benchmarks_results(args):
     """Show benchmark results"""
     found_benchmarks = search_for_benchmarks(args)
     result_list = list()
+
     # Start with the newest benchmark to set the newest result configuration
     found_benchmarks.reverse()
     cnt = 0
@@ -84,7 +85,6 @@ def benchmarks_results(args):
                                             args=args,
                                             result_list=result_list)
             cnt += 1
-
     for result_data in result_list:
         result_data.create_result(reverse=args.reverse)
 
@@ -222,6 +222,11 @@ def _load_existing_benchmark(args, benchmark_folder, restore_workpackages=True,
     jube2.log.change_logfile_name(os.path.join(
         benchmark_folder, jube2.conf.LOGFILE_PARSE_NAME))
 
+    # Add log information
+    LOGGER.debug("Command: {0} {1}".format(
+        os.path.basename(sys.argv[0]), " ".join(sys.argv[1:])))
+    LOGGER.debug("Version: {0}".format(jube2.conf.JUBE_VERSION))
+
     # Read existing benchmark configuration
     try:
         parser = jube2.jubeio.XMLParser(os.path.join(
@@ -350,6 +355,12 @@ def run_new_benchmark(args):
         jube2.log.change_logfile_name(
             filename=os.path.join(os.path.dirname(path),
                                   jube2.conf.DEFAULT_LOGFILE_NAME))
+
+        # Add log information
+        LOGGER.debug("Command: {0} {1}".format(
+            os.path.basename(sys.argv[0]), " ".join(sys.argv[1:])))
+        LOGGER.debug("Version: {0}".format(jube2.conf.JUBE_VERSION))
+
         # Read new benchmarks
         if args.include_path is not None:
             include_pathes = [include_path for include_path in
@@ -388,6 +399,10 @@ def run_new_benchmark(args):
                     continue
                 bench.id = args.id[id_cnt]
                 id_cnt += 1
+            # Change runtime outpath if specified
+            if args.outpath is not None:
+                bench.outpath = args.outpath
+            # Start benchmark run
             bench.new_run()
             # Run analyse
             if args.analyse or args.result:
@@ -505,7 +520,8 @@ def _benchmark_result(benchmark_folder, args, result_list=None):
 
     # Create benchmark results
     result_list = benchmark.create_result(only=args.only,
-                                          data_list=result_list)
+                                          data_list=result_list,
+                                          style=args.style)
 
     # Reset logging
     jube2.log.only_console_log()
@@ -518,11 +534,9 @@ def _update_analyse_and_result(args, benchmark):
     given update file"""
     if args.update is not None:
         dirname = os.path.dirname(args.update)
-
         # Extract tags
-        tags = args.tag
-        if tags is not None:
-            tags = set(tags)
+        benchmark.add_tags(args.tag)
+        tags = benchmark.tags
 
         # Read new benchmarks
         if args.include_path is not None:
@@ -646,7 +660,9 @@ def gen_subparser_conf():
             ("-r", "--result"):
                 {"action": "store_true", "help": "show results"},
             ("-m", "--comment"):
-                {"help": "add comment"}
+                {"help": "add comment"},
+            ("-o", "--outpath"):
+                {"help": "overwrite outpath directory"}
         }
     }
 
@@ -721,7 +737,10 @@ def gen_subparser_conf():
                 {"help": "reverse benchmark output order",
                  "action": "store_true"},
             ("-n", "--num"):
-                {"type": int, "help": "show only last N benchmarks"}
+                {"type": int, "help": "show only last N benchmarks"},
+            ("-s", "--style"):
+                {"help": "overwrites table style type",
+                 "choices": ["pretty", "csv"]}
         }
     }
 
@@ -888,6 +907,7 @@ def _get_args_parser():
 
 def main(command=None):
     """Parse the command line and run the requested command."""
+
     jube2.help.load_help()
     parser = _get_args_parser()[0]
     if command is None:
